@@ -1,5 +1,5 @@
 package PDL::Factor;
-$PDL::Factor::VERSION = '0.006001';
+$PDL::Factor::VERSION = '0.006002';
 # ABSTRACT: PDL subclass for keeping categorical data
 
 use 5.016;
@@ -241,7 +241,7 @@ sub _call_on_pdl {
     };
 }
 
-for my $method (qw(isbad isgood)) {
+for my $method (qw(isbad isgood ngood nbad)) {
     no strict 'refs';
     *{$method} = _call_on_pdl($method);
 }
@@ -334,7 +334,7 @@ PDL::Factor - PDL subclass for keeping categorical data
 
 =head1 VERSION
 
-version 0.006001
+version 0.006002
 
 =head1 SYNOPSIS
 
